/*-
 * Copyright (c) 2014 Varnish Software AS
 * All rights reserved.
 *
 * Author: Poul-Henning Kamp <phk@phk.freebsd.dk>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 */

/*lint -save -e525 -e539 */

/*
 <blink>

 ***********************************************************
 * #     #    #    ######  #     #   ###   #     #  #####  *
 * #  #  #   # #   #     # ##    #    #    ##    # #     # *
 * #  #  #  #   #  #     # # #   #    #    # #   # #       *
 * #  #  # #     # ######  #  #  #    #    #  #  # #  #### *
 * #  #  # ####### #   #   #   # #    #    #   # # #     # *
 * #  #  # #     # #    #  #    ##    #    #    ## #     # *
 *  ## ##  #     # #     # #     #   ###   #     #  #####  *
 *                                                         *
 *   Most any changes in this file will change on-disk     *
 *                   data structures                       *
 ***********************************************************

 </blink>
*/

/* FIXATTR: UPPER, lower, attr_no, size */
#ifndef OBJ_FIXATTR
# define OBJ_FIXATTR(U, l, n, s)
#endif

/* VARATTR: UPPER, lower, attr_no */
#ifndef OBJ_VARATTR
# define OBJ_VARATTR(U, l, n)
#endif

/* AUXATTR: UPPER, lower, attr_no */
#ifndef OBJ_AUXATTR
# define OBJ_AUXATTR(U, l, n)
#endif

/******************************************************************************/
/* Well-known object attributes */

/* IMPORTANT NOTE: These are the set of well-known always present
 * attributes, and can not be modified. Doing so will corrupt persisted
 * caches. */
/*		UPPER		lower		attr_no		len	*/
#ifndef OBJ_SKIPATTR_LEN
OBJ_FIXATTR(	LEN,		len,		0,		8)
#endif
#ifndef OBJ_SKIPATTR_VXID
OBJ_FIXATTR(	VXID,		vxid,		1,		4)
#endif
OBJ_FIXATTR(	FLAGS,		flags,		2,		1)
OBJ_FIXATTR(	COMPBITS,	compbits,	3,		32)
OBJ_FIXATTR(	LASTMODIFIED,	lastmodified,	4,		8)
OBJ_FIXATTR(	CRYPTOPAD,	cryptopad,	5,		24)

OBJ_VARATTR(	VARY,		vary,		6)
OBJ_VARATTR(	HEADERS,	headers,	7)

OBJ_AUXATTR(	EXTRADATA,	extradata,	8)
OBJ_AUXATTR(	JSONDATA,	jsondata,	9)
OBJ_AUXATTR(	XBODYDATA,	xbodydata,	10)

#undef OBJ_FIXATTR

/******************************************************************************/
/* Extra attributes */

/* These are extra attributes that are optionally used
 * depending on the object. Notice that these may only be varattrs or
 * auxattrs. */

/* IMPORTANT NOTE: attr_no needs to be an eternally unique value. This
 * means if an attribute is later removed, it's assigned value should be
 * kept in a comment here so that it isn't reassigned again later. */

/* OBJ_VARATTR(SLICE_SEG_LEN, slice_seg_len, 11) */
OBJ_VARATTR(SLICERDATA,	slicerdata, 12)

#undef OBJ_VARATTR
#undef OBJ_AUXATTR

/******************************************************************************/
/* Object flags */

/* IMPORTANT NOTE: The flags fixattr is only 1 byte wide (and can not be
 * changed). The bits may not be changed, doing so will corrupt persisted
 * caches. */

#ifdef OBJ_FLAG
/* upper, lower, val */
  OBJ_FLAG(GZIPED,	gziped,		(1<<1))
  OBJ_FLAG(CHGCE,	chgce,		(1<<2))
  OBJ_FLAG(IMSCAND,	imscand,	(1<<3))
  OBJ_FLAG(ESIPROC,	esiproc,	(1<<4))
  OBJ_FLAG(VESPROC,	vesproc,	(1<<5))
  OBJ_FLAG(JSONPROC,	jsonproc,	(1<<6))
  OBJ_FLAG(BROTLIED,	brotlied,	(1<<7))

  #undef OBJ_FLAG
#endif

#undef OBJ_SKIPATTR_LEN
#undef OBJ_SKIPATTR_VXID

/*lint -restore */
